@@ -32,6 +32,19 @@ DATABASES = {
     },
 }
 
+ROOT_URLCONF = 'eox_tagging.urls'
+
+# Internationalization
+# https://docs.djangoproject.com/en/1.11/topics/i18n/
+
+LANGUAGE_CODE = 'en-us'
+
+TIME_ZONE = 'UTC'
+
+USE_TZ = True
+
+ALLOWED_HOSTS = ['*']
+
 EOX_TAGGING_SKIP_VALIDATIONS = True
 EOX_TAGGING_LOAD_PERMISSIONS = False
 DATA_API_DEF_PAGE_SIZE = 1000
