@@ -7,6 +7,7 @@ from django.contrib.auth.models import User
 from django.contrib.sites.models import Site
 from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.test import TestCase, override_settings
+from django.utils import timezone
 from opaque_keys.edx.keys import CourseKey
 
 from eox_tagging.constants import AccessLevel
@@ -118,6 +119,94 @@ class TestTag(TestCase):
                 access=AccessLevel.PRIVATE,
             )
 
+    @override_settings(
+        EOX_TAGGING_DEFINITIONS=[
+            {
+                "tag_type": "subscription_tier",
+                "force_access": "private",
+                "validate_tag_value": {"in": ["free", "private"]},
+                "validate_owner_object": "User",
+                "validate_target_object": "User",
+            },
+        ])
+    def test_force_access_configuration(self):
+        """
+        Used to test that if a field is `forced` then it must be set to the value
+        specified."""
+        tag = Tag.objects.create_tag(
+            tag_value="free",
+            tag_type="subscription_tier",
+            target_object=self.target_object,
+            owner_object=self.owner_object,
+        )
+
+        self.assertIsNotNone(tag.id)
+        self.assertEqual(tag.access.name, "PRIVATE")
+
+    @override_settings(
+        EOX_TAGGING_DEFINITIONS=[
+            {
+                "tag_type": "subscription_tier",
+                "force_activation_date": "2020-10-19 10:20:30",
+                "validate_tag_value": {"in": ["free", "private"]},
+                "validate_owner_object": "User",
+                "validate_target_object": "User",
+            },
+        ])
+    def test_force_activation_date_configuration(self):
+        """Used to test that if a field is `forced` the must be set to the value specified."""
+        tag = Tag.objects.create_tag(
+            tag_value="free",
+            tag_type="subscription_tier",
+            target_object=self.target_object,
+            owner_object=self.owner_object,
+        )
+
+        self.assertIsNotNone(tag.id)
+        self.assertEqual(str(tag.activation_date), "2020-10-19 10:20:30")
+
+    @override_settings(
+        EOX_TAGGING_DEFINITIONS=[
+            {
+                "tag_type": "subscription_tier",
+                "force_expiration_date": "2020-10-19 10:20:30",
+                "validate_tag_value": {"in": ["free", "private"]},
+                "validate_owner_object": "User",
+                "validate_target_object": "User",
+            },
+        ])
+    def test_force_expiration_date_configuration(self):
+        """Used to test that if a field is `forced` the must be set to the value specified."""
+        tag = Tag.objects.create_tag(
+            tag_value="free",
+            tag_type="subscription_tier",
+            target_object=self.target_object,
+            owner_object=self.owner_object,
+        )
+
+        self.assertIsNotNone(tag.id)
+        self.assertEqual(str(tag.expiration_date), "2020-10-19 10:20:30")
+
+    @override_settings(
+        EOX_TAGGING_DEFINITIONS=[
+            {
+                "tag_type": "subscription_tier",
+                "force_tag_value": "free",
+                "validate_owner_object": "User",
+                "validate_target_object": "User",
+            },
+        ])
+    def test_force_tag_value_configuration(self):
+        """Used to test that if a field is `forced` the must be set to the value specified."""
+        tag = Tag.objects.create_tag(
+            tag_type="subscription_tier",
+            target_object=self.target_object,
+            owner_object=self.owner_object,
+        )
+
+        self.assertIsNotNone(tag.id)
+        self.assertEqual(tag.tag_value, "free")
+
     @override_settings(
         EOX_TAGGING_DEFINITIONS=[
             {
@@ -236,7 +325,7 @@ class TestTag(TestCase):
                 expiration_date=datetime.date(2020, 10, 19),
             )
 
-    def test_tag_inmutable(self):
+    def test_tag_immutable(self):
         """ Used to confirm that the tags can't be updated."""
         setattr(self.test_tag, "tag_value", "value")
         with self.assertRaises(ValidationError):
@@ -255,14 +344,16 @@ class TestTag(TestCase):
         self.assertEqual(tags.first().target_object_id, self.target_object.id)
 
     def test_tag_soft_delete(self):
-        """ Used to confirm that the tags can be invalidated soft deleting them."""
+        """
+        Used to confirm that the tags can be invalidated soft deleting them.
+        This also means that they will no longer exist in active tags set.
+        """
         self.test_tag.delete()
 
+        deleted_tag = Tag.objects.inactive().get(id=self.test_tag.id)
         with self.assertRaises(ObjectDoesNotExist):
-            Tag.objects.active().get(id=1)
-
-        # Exists in invalid objects
-        Tag.objects.inactive().get(id=1)
+            Tag.objects.active().get(id=self.test_tag.id)
+        self.assertGreater(timezone.now(), deleted_tag.inactivated_at)
 
     def test_create_tag_without_target_object(self):
         """
@@ -422,3 +513,9 @@ class TestTag(TestCase):
                 expiration_date=datetime.datetime(2020, 4, 19, 10, 20, 30),
                 activation_date=datetime.datetime(2020, 6, 16, 10, 20, 30),
             )
+
+    def test_soft_delete_queryset(self):
+        """Used to test deactivating tags using a tag queryset."""
+        Tag.objects.delete()
+
+        self.assertFalse(Tag.objects.active())
